package com.cpms.project.safety.service.impl;

import com.cpms.project.safety.domain.TSafetyFiles;
import com.cpms.project.safety.mapper.TSafetyFilesMapper;
import com.cpms.project.safety.service.ITSafetyFilesService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 安全设备设施检查附件Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-05-25
 */
@Service
public class TSafetyFilesServiceImpl implements ITSafetyFilesService
{
    @Autowired
    private TSafetyFilesMapper tSafetyFilesMapper;

    /**
     * 查询安全设备设施检查附件
     * 
     * @param id 安全设备设施检查附件主键
     * @return 安全设备设施检查附件
     */
    @Override
    public TSafetyFiles selectTSafetyFilesById(Long id)
    {
        return tSafetyFilesMapper.selectTSafetyFilesById(id);
    }

    /**
     * 查询安全设备设施检查附件列表
     * 
     * @param tSafetyFiles 安全设备设施检查附件
     * @return 安全设备设施检查附件
     */
    @Override
    public List<TSafetyFiles> selectTSafetyFilesList(TSafetyFiles tSafetyFiles)
    {
        return tSafetyFilesMapper.selectTSafetyFilesList(tSafetyFiles);
    }

    /**
     * 新增安全设备设施检查附件
     * 
     * @param tSafetyFiles 安全设备设施检查附件
     * @return 结果
     */
    @Override
    public int insertTSafetyFiles(TSafetyFiles tSafetyFiles)
    {
        return tSafetyFilesMapper.insertTSafetyFiles(tSafetyFiles);
    }

    /**
     * 修改安全设备设施检查附件
     * 
     * @param tSafetyFiles 安全设备设施检查附件
     * @return 结果
     */
    @Override
    public int updateTSafetyFiles(TSafetyFiles tSafetyFiles)
    {
        return tSafetyFilesMapper.updateTSafetyFiles(tSafetyFiles);
    }

    /**
     * 批量删除安全设备设施检查附件
     * 
     * @param ids 需要删除的安全设备设施检查附件主键
     * @return 结果
     */
    @Override
    public int deleteTSafetyFilesByIds(Long[] ids)
    {
        return tSafetyFilesMapper.deleteTSafetyFilesByIds(ids);
    }

    /**
     * 删除安全设备设施检查附件信息
     * 
     * @param id 安全设备设施检查附件主键
     * @return 结果
     */
    @Override
    public int deleteTSafetyFilesById(Long id)
    {
        return tSafetyFilesMapper.deleteTSafetyFilesById(id);
    }
}
